@@ -35,6 +35,9 @@ public slots:
     void updateList(const MessageList &list);
     void readMessage(const QString &accountId, const QString &messageId);
 
+signals:
+    void messageCountChanged(int newCount);
+
 private:
     MessageList shownMessagesList;
 
